#define PCI_CONFIG_H
#define PCI_ARCH_ARMV5TEL
#define PCI_OS_LINUX
#define PCI_HAVE_PM_LINUX_SYSFS
#define PCI_HAVE_PM_LINUX_PROC
#define PCI_HAVE_LINUX_BYTEORDER_H
#define PCI_PATH_PROC_BUS_PCI "/proc/bus/pci"
#define PCI_PATH_SYS_BUS_PCI "/sys/bus/pci"
#define PCI_HAVE_64BIT_ADDRESS
#define PCI_HAVE_PM_DUMP
#define PCI_COMPRESSED_IDS
#define PCI_IDS "pci.ids.gz"
#define PCI_PATH_IDS_DIR "/usr/share/hwdata"
#define PCI_USE_DNS
#define PCI_ID_DOMAIN "pci.id.ucw.cz"
#define PCILIB_VERSION "3.1.9"
